@@ -14,6 +14,8 @@
 
 #define QT_FEATURE_private_tests -1
 
+#define QT_FEATURE_doc_snippets -1
+
 #define QT_FEATURE_debug -1
 
 #define QT_FEATURE_elf_private_full_version -1
@@ -70,6 +72,10 @@
 
 #define QT_FEATURE_shani 1
 
+#define QT_FEATURE_lsx -1
+
+#define QT_FEATURE_lasx -1
+
 #define QT_FEATURE_mips_dsp -1
 
 #define QT_FEATURE_mips_dspr2 -1
@@ -80,17 +86,17 @@
 
 #define QT_FEATURE_arm_crypto -1
 
+#define QT_FEATURE_arm_sve -1
+
 #define QT_FEATURE_localtime_r 1
 
 #define QT_FEATURE_localtime_s -1
 
 #define QT_FEATURE_posix_fallocate 1
 
-#define QT_FEATURE_alloca_h 1
+#define QT_FEATURE_force_system_libs -1
 
-#define QT_FEATURE_alloca_malloc_h -1
-
-#define QT_FEATURE_alloca 1
+#define QT_FEATURE_force_bundled_libs -1
 
 #define QT_FEATURE_system_zlib 1
 
