@@ -1,5 +1,7 @@
 #define QT_FEATURE_accessibility_atspi_bridge -1
 
+#define QT_FEATURE_emojisegmenter 1
+
 #define QT_FEATURE_freetype 1
 
 #define QT_FEATURE_fontconfig 1
@@ -110,4 +112,6 @@
 
 #define QT_FEATURE_wayland 1
 
+#define QT_FEATURE_waylandscanner 1
+
 #define QT_NO_ACCESSIBILITY_ATSPI_BRIDGE 1
